Bandwagon
=========

Bandwagon (full documentation `here
<http://edinburgh-genome-foundry.github.io/BandWagon/>`_) is a Python library to predict and plot migration patterns
from DNA digestions. It supports hundreds of different enzymes (thanks to BioPython),
single- and multiple-enzymes digestions, and custom ladders.

It uses Matplotlib to produce plots like this one:

.. figure:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/BandWagon/master/examples/mixed_digestions.png
    :align: center

Infos
-----

**PIP installation:**

.. code:: bash

  pip install bandwagon

**Web documentation:**

`<https://edinburgh-genome-foundry.github.io/bandwagon/>`_

**Github Page**

`<https://github.com/Edinburgh-Genome-Foundry/bandwagon>`_

**Live demo**

`<https://cuba.genomefoundry.org/predict-digestions>`_

**License:** MIT, Copyright Edinburgh Genome Foundry

More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Bandwagon is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
